@@ -25,8 +25,8 @@
 
 namespace LibreNMS\DB;
 
-use DB;
 use Illuminate\Database\Connection;
+use Illuminate\Support\Facades\DB;
 use LibreNMS\Util\Laravel;
 use PDOException;
 
