@@ -26,6 +26,7 @@
 namespace LibreNMS\Interfaces\UI;
 
 use App\Models\Device;
+use Illuminate\Http\Request;
 
 interface DeviceTab
 {
@@ -62,7 +63,8 @@ interface DeviceTab
      * Collect data to send to the view
      *
      * @param  Device  $device
+     * @param  Request  $request
      * @return array
      */
-    public function data(Device $device): array;
+    public function data(Device $device, Request $request): array;
 }
