@@ -134,7 +134,7 @@ class Panos extends \LibreNMS\OS implements OSPolling
             $this->enableGraph('panos_sessions_ssl');
         }
 
-        if (is_numeric($data[0]['panSessionSslProxyUtilization'])) {
+        if (is_numeric($data[0]['panSessionSslProxyUtilization'] ?? null)) {
             $rrd_def = RrdDefinition::make()->addDataset('sessions_sslutil', 'GAUGE', 0, 3000000);
 
             $fields = [
@@ -147,7 +147,7 @@ class Panos extends \LibreNMS\OS implements OSPolling
             $this->enableGraph('panos_sessions_sslutil');
         }
 
-        if (is_numeric($data[0]['panGPGWUtilizationActiveTunnels'])) {
+        if (is_numeric($data[0]['panGPGWUtilizationActiveTunnels'] ?? null)) {
             $rrd_def = RrdDefinition::make()->addDataset('activetunnels', 'GAUGE', 0, 3000000);
 
             $fields = [
@@ -159,7 +159,7 @@ class Panos extends \LibreNMS\OS implements OSPolling
 
             $this->enableGraph('panos_activetunnels');
         }
-        if (is_numeric($data[0]['panFlowDosBlkNumEntries'])) {
+        if (is_numeric($data[0]['panFlowDosBlkNumEntries'] ?? null)) {
             $rrd_def = RrdDefinition::make()->addDataset('panFlowDosBlkNumEntries', 'GAUGE', 0);
 
             $fields = [
@@ -171,7 +171,7 @@ class Panos extends \LibreNMS\OS implements OSPolling
 
             $this->enableGraph('panos_panFlowDosBlkNumEntries');
         }
-        if (is_numeric($data[0]['panFlowMeterVsysThrottle'])) {
+        if (is_numeric($data[0]['panFlowMeterVsysThrottle'] ?? null)) {
             $rrd_def = RrdDefinition::make()->addDataset('panFlowMeterVsysThrottle', 'COUNTER', 0);
 
             $fields = [
@@ -183,7 +183,7 @@ class Panos extends \LibreNMS\OS implements OSPolling
 
             $this->enableGraph('panos_panFlowMeterVsysThrottle');
         }
-        if (is_numeric($data[0]['panFlowPolicyDeny'])) {
+        if (is_numeric($data[0]['panFlowPolicyDeny'] ?? null)) {
             $rrd_def = RrdDefinition::make()->addDataset('panFlowPolicyDeny', 'COUNTER', 0);
 
             $fields = [
@@ -195,7 +195,7 @@ class Panos extends \LibreNMS\OS implements OSPolling
 
             $this->enableGraph('panos_panFlowPolicyDeny');
         }
-        if (is_numeric($data[0]['panFlowPolicyNat'])) {
+        if (is_numeric($data[0]['panFlowPolicyNat'] ?? null)) {
             $rrd_def = RrdDefinition::make()->addDataset('panFlowPolicyNat', 'COUNTER', 0);
 
             $fields = [
@@ -207,7 +207,7 @@ class Panos extends \LibreNMS\OS implements OSPolling
 
             $this->enableGraph('panos_panFlowPolicyNat');
         }
-        if (is_numeric($data[0]['panFlowScanDrop'])) {
+        if (is_numeric($data[0]['panFlowScanDrop'] ?? null)) {
             $rrd_def = RrdDefinition::make()->addDataset('panFlowScanDrop', 'COUNTER', 0);
 
             $fields = [
@@ -219,7 +219,7 @@ class Panos extends \LibreNMS\OS implements OSPolling
 
             $this->enableGraph('panos_panFlowScanDrop');
         }
-        if (is_numeric($data[0]['panFlowDosDropIpBlocked'])) {
+        if (is_numeric($data[0]['panFlowDosDropIpBlocked'] ?? null)) {
             $rrd_def = RrdDefinition::make()->addDataset('panFlowDosDropIpBlocked', 'COUNTER', 0);
 
             $fields = [
@@ -231,7 +231,7 @@ class Panos extends \LibreNMS\OS implements OSPolling
 
             $this->enableGraph('panos_panFlowDosDropIpBlocked');
         }
-        if (is_numeric($data[0]['panFlowDosRedIcmp'])) {
+        if (is_numeric($data[0]['panFlowDosRedIcmp'] ?? null)) {
             $rrd_def = RrdDefinition::make()->addDataset('panFlowDosRedIcmp', 'COUNTER', 0);
 
             $fields = [
@@ -243,7 +243,7 @@ class Panos extends \LibreNMS\OS implements OSPolling
 
             $this->enableGraph('panos_panFlowDosRedIcmp');
         }
-        if (is_numeric($data[0]['panFlowDosRedIcmp6'])) {
+        if (is_numeric($data[0]['panFlowDosRedIcmp6'] ?? null)) {
             $rrd_def = RrdDefinition::make()->addDataset('panFlowDosRedIcmp6', 'COUNTER', 0);
 
             $fields = [
@@ -255,7 +255,7 @@ class Panos extends \LibreNMS\OS implements OSPolling
 
             $this->enableGraph('panos_panFlowDosRedIcmp6');
         }
-        if (is_numeric($data[0]['panFlowDosRedIp'])) {
+        if (is_numeric($data[0]['panFlowDosRedIp'] ?? null)) {
             $rrd_def = RrdDefinition::make()->addDataset('panFlowDosRedIp', 'COUNTER', 0);
 
             $fields = [
@@ -267,7 +267,7 @@ class Panos extends \LibreNMS\OS implements OSPolling
 
             $this->enableGraph('panos_panFlowDosRedIp');
         }
-        if (is_numeric($data[0]['panFlowDosRedTcp'])) {
+        if (is_numeric($data[0]['panFlowDosRedTcp'] ?? null)) {
             $rrd_def = RrdDefinition::make()->addDataset('panFlowDosRedTcp', 'COUNTER', 0);
 
             $fields = [
@@ -279,7 +279,7 @@ class Panos extends \LibreNMS\OS implements OSPolling
 
             $this->enableGraph('panos_panFlowDosRedTcp');
         }
-        if (is_numeric($data[0]['panFlowDosRedUdp'])) {
+        if (is_numeric($data[0]['panFlowDosRedUdp'] ?? null)) {
             $rrd_def = RrdDefinition::make()->addDataset('panFlowDosRedUdp', 'COUNTER', 0);
 
             $fields = [
@@ -291,7 +291,7 @@ class Panos extends \LibreNMS\OS implements OSPolling
 
             $this->enableGraph('panos_panFlowDosRedUdp');
         }
-        if (is_numeric($data[0]['panFlowDosPbpDrop'])) {
+        if (is_numeric($data[0]['panFlowDosPbpDrop'] ?? null)) {
             $rrd_def = RrdDefinition::make()->addDataset('panFlowDosPbpDrop', 'COUNTER', 0);
 
             $fields = [
@@ -303,7 +303,7 @@ class Panos extends \LibreNMS\OS implements OSPolling
 
             $this->enableGraph('panos_panFlowDosPbpDrop');
         }
-        if (is_numeric($data[0]['panFlowDosRuleDeny'])) {
+        if (is_numeric($data[0]['panFlowDosRuleDeny'] ?? null)) {
             $rrd_def = RrdDefinition::make()->addDataset('panFlowDosRuleDeny', 'COUNTER', 0);
 
             $fields = [
@@ -315,7 +315,7 @@ class Panos extends \LibreNMS\OS implements OSPolling
 
             $this->enableGraph('panos_panFlowDosRuleDeny');
         }
-        if (is_numeric($data[0]['panFlowDosRuleDrop'])) {
+        if (is_numeric($data[0]['panFlowDosRuleDrop'] ?? null)) {
             $rrd_def = RrdDefinition::make()->addDataset('panFlowDosRuleDrop', 'COUNTER', 0);
 
             $fields = [
@@ -327,7 +327,7 @@ class Panos extends \LibreNMS\OS implements OSPolling
 
             $this->enableGraph('panos_panFlowDosRuleDrop');
         }
-        if (is_numeric($data[0]['panFlowDosZoneRedAct'])) {
+        if (is_numeric($data[0]['panFlowDosZoneRedAct'] ?? null)) {
             $rrd_def = RrdDefinition::make()->addDataset('panFlowDosZoneRedAct', 'COUNTER', 0);
 
             $fields = [
@@ -339,7 +339,7 @@ class Panos extends \LibreNMS\OS implements OSPolling
 
             $this->enableGraph('panos_panFlowDosZoneRedAct');
         }
-        if (is_numeric($data[0]['panFlowDosZoneRedMax'])) {
+        if (is_numeric($data[0]['panFlowDosZoneRedMax'] ?? null)) {
             $rrd_def = RrdDefinition::make()->addDataset('panFlowDosZoneRedMax', 'COUNTER', 0);
 
             $fields = [
@@ -351,7 +351,7 @@ class Panos extends \LibreNMS\OS implements OSPolling
 
             $this->enableGraph('panos_panFlowDosZoneRedMax');
         }
-        if (is_numeric($data[0]['panFlowDosSyncookieNotTcpSyn'])) {
+        if (is_numeric($data[0]['panFlowDosSyncookieNotTcpSyn'] ?? null)) {
             $rrd_def = RrdDefinition::make()->addDataset('panFlowDosSyncookieNotTcpSyn', 'COUNTER', 0);
 
             $fields = [
@@ -363,7 +363,7 @@ class Panos extends \LibreNMS\OS implements OSPolling
 
             $this->enableGraph('panos_panFlowDosSyncookieNotTcpSyn');
         }
-        if (is_numeric($data[0]['panFlowDosSyncookieNotTcpSynAck'])) {
+        if (is_numeric($data[0]['panFlowDosSyncookieNotTcpSynAck'] ?? null)) {
             $rrd_def = RrdDefinition::make()->addDataset('panFlowDosSyncookieNotTcpSynAck', 'COUNTER', 0);
 
             $fields = [
@@ -375,7 +375,7 @@ class Panos extends \LibreNMS\OS implements OSPolling
 
             $this->enableGraph('panos_panFlowDosSyncookieNotTcpSynAck');
         }
-        if (is_numeric($data[0]['panFlowDosBlkSwEntries'])) {
+        if (is_numeric($data[0]['panFlowDosBlkSwEntries'] ?? null)) {
             $rrd_def = RrdDefinition::make()->addDataset('panFlowDosBlkSwEntries', 'GAUGE', 0);
 
             $fields = [
@@ -387,7 +387,7 @@ class Panos extends \LibreNMS\OS implements OSPolling
 
             $this->enableGraph('panos_panFlowDosBlkSwEntries');
         }
-        if (is_numeric($data[0]['panFlowDosBlkHwEntries'])) {
+        if (is_numeric($data[0]['panFlowDosBlkHwEntries'] ?? null)) {
             $rrd_def = RrdDefinition::make()->addDataset('panFlowDosBlkHwEntries', 'GAUGE', 0);
 
             $fields = [
