@@ -25,6 +25,7 @@
 
 namespace LibreNMS\OS;
 
+use Illuminate\Support\Facades\Log;
 use LibreNMS\Device\Processor;
 use LibreNMS\Interfaces\Data\DataStorageInterface;
 use LibreNMS\Interfaces\Discovery\ProcessorDiscovery;
@@ -59,7 +60,7 @@ class Sgos extends OS implements ProcessorDiscovery, OSPolling
             $datastore->put($this->getDeviceArray(), 'sgos_average_requests', $tags, $fields);
 
             $this->enableGraph('sgos_average_requests');
-            echo ' HTTP Req Rate';
+            Log::info(' HTTP Req Rate');
         }
 
         if (is_numeric($sgos[0]['sgProxyHttpClientConnections'] ?? null)) {
@@ -73,7 +74,7 @@ class Sgos extends OS implements ProcessorDiscovery, OSPolling
             $datastore->put($this->getDeviceArray(), 'sgos_client_connections', $tags, $fields);
 
             $this->enableGraph('sgos_client_connections');
-            echo ' Client Conn';
+            Log::info(' Client Conn');
         }
 
         if (is_numeric($sgos[0]['sgProxyHttpServerConnections'] ?? null)) {
@@ -87,7 +88,7 @@ class Sgos extends OS implements ProcessorDiscovery, OSPolling
             $datastore->put($this->getDeviceArray(), 'sgos_server_connections', $tags, $fields);
 
             $this->enableGraph('sgos_server_connections');
-            echo ' Server Conn';
+            Log::info(' Server Conn');
         }
 
         if (is_numeric($sgos[0]['sgProxyHttpClientConnectionsActive'] ?? null)) {
@@ -101,7 +102,7 @@ class Sgos extends OS implements ProcessorDiscovery, OSPolling
             $datastore->put($this->getDeviceArray(), 'sgos_client_connections_active', $tags, $fields);
 
             $this->enableGraph('sgos_client_connections_active');
-            echo ' Client Conn Active';
+            Log::info(' Client Conn Active');
         }
 
         if (is_numeric($sgos[0]['sgProxyHttpServerConnectionsActive'] ?? null)) {
@@ -115,7 +116,7 @@ class Sgos extends OS implements ProcessorDiscovery, OSPolling
             $datastore->put($this->getDeviceArray(), 'sgos_server_connections_active', $tags, $fields);
 
             $this->enableGraph('sgos_server_connections_active');
-            echo ' Server Conn Active';
+            Log::info(' Server Conn Active');
         }
 
         if (is_numeric($sgos[0]['sgProxyHttpClientConnectionsIdle'] ?? null)) {
@@ -129,7 +130,7 @@ class Sgos extends OS implements ProcessorDiscovery, OSPolling
             $datastore->put($this->getDeviceArray(), 'sgos_client_connections_idle', $tags, $fields);
 
             $this->enableGraph('sgos_client_connections_idle');
-            echo ' Client Conne Idle';
+            Log::info(' Client Conne Idle');
         }
 
         if (is_numeric($sgos[0]['sgProxyHttpServerConnectionsIdle'] ?? null)) {
@@ -143,7 +144,7 @@ class Sgos extends OS implements ProcessorDiscovery, OSPolling
             $datastore->put($this->getDeviceArray(), 'sgos_server_connections_idle', $tags, $fields);
 
             $this->enableGraph('sgos_server_connections_idle');
-            echo ' Server Conn Idle';
+            Log::info(' Server Conn Idle');
         }
     }
 
