@@ -10,18 +10,31 @@
  */
 
 use LibreNMS\Billing;
+use LibreNMS\Config;
+use LibreNMS\Util\Debug;
 use LibreNMS\Util\Number;
 
 $init_modules = [];
 require __DIR__ . '/includes/init.php';
 
-$options = getopt('r');
+$options = getopt('frd');
 
 if (isset($options['r'])) {
     echo "Clearing history table.\n";
     DB::table('bill_history')->truncate();
 }
 
+Debug::set(isset($options['d']));
+
+$scheduler = Config::get('schedule_type.billing');
+if (! isset($options['f']) && $scheduler != 'legacy' && $scheduler != 'cron') {
+    if (Debug::isEnabled()) {
+        echo "Billing is not enabled for cron scheduling.  Add the -f command ar
+gument if you want to force this command to run.\n";
+    }
+    exit(0);
+}
+
 foreach (dbFetchRows('SELECT * FROM `bills` ORDER BY `bill_id`') as $bill) {
     echo str_pad($bill['bill_id'] . ' ' . $bill['bill_name'], 30) . " \n";
 
