@@ -130,7 +130,7 @@ set_notifiable_result() {
 #   Exit-Code: 0 >= min ver, 1 < min ver
 #######################################
 check_dependencies() {
-    local branch ver_71 ver_72 ver_73 ver_81 python3 python_deps phpver pythonver old_branches msg
+    local branch ver_71 ver_72 ver_73 ver_81 ver_82 python3 python_deps phpver pythonver old_branches msg
 
     branch=master
     scripts/check_requirements.py > /dev/null 2>&1 || pip3 install -r requirements.txt > /dev/null 2>&1
@@ -139,13 +139,14 @@ check_dependencies() {
     ver_72=$(/usr/local/bin/php-8.2 -r "echo (int)version_compare(PHP_VERSION, '7.2.5', '<');")
     ver_73=$(/usr/local/bin/php-8.2 -r "echo (int)version_compare(PHP_VERSION, '7.3', '<');")
     ver_81=$(/usr/local/bin/php-8.2 -r "echo (int)version_compare(PHP_VERSION, '8.1', '<');")
+    ver_82=$(/usr/local/bin/php-8.2 -r "echo (int)version_compare(PHP_VERSION, '8.2', '<');")
     python3=$(python3 -c "import sys;print(int(sys.version_info < (3, 4)))" 2> /dev/null)
     python_deps=$("${LIBRENMS_DIR}/scripts/check_requirements.py" > /dev/null 2>&1; echo $?)
     phpver="master"
     pythonver="master"
 
-    old_branches="^(php53|php56|php71-python2|php72|php73)$"
-    if [[ $branch =~ $old_branches ]] && [[ "$ver_81" == "0" && "$python3" == "0" && "$python_deps" == "0" ]]; then
+    old_branches="^(php53|php56|php71-python2|php72|php73|php81)$"
+    if [[ $branch =~ $old_branches ]] && [[ "$ver_82" == "0" && "$python3" == "0" && "$python_deps" == "0" ]]; then
         status_run "Supported PHP and Python version, switched back to master branch." 'git checkout master'
     elif [[ "$ver_71" != "0" ]]; then
         phpver="php56"
@@ -179,6 +180,11 @@ check_dependencies() {
         if [[ "$branch" != "php73" ]]; then
             status_run "Unsupported PHP version, switched to php73 branch." 'git checkout php73'
         fi
+    elif [[ "$ver_82" != "0" ]]; then
+        phpver="php81"
+        if [[ "$branch" != "php81" ]]; then
+            status_run "Unsupported PHP version, switched to php81 branch." 'git checkout php81'
+        fi
     fi
 
     set_notifiable_result phpver ${phpver}
