@@ -4,14 +4,14 @@ use App\Models\PortsFdb;
 use Illuminate\Database\Migrations\Migration;
 use Illuminate\Database\Schema\Blueprint;
 
-class AddDatesToFdb extends Migration
+return new class extends Migration
 {
     /**
      * Run the migrations.
      *
      * @return void
      */
-    public function up()
+    public function up(): void
     {
         Schema::table('ports_fdb', function (Blueprint $table) {
             $table->timestamps();
@@ -27,10 +27,10 @@ class AddDatesToFdb extends Migration
      *
      * @return void
      */
-    public function down()
+    public function down(): void
     {
         Schema::table('ports_fdb', function (Blueprint $table) {
             $table->dropColumn(['created_at', 'updated_at']);
         });
     }
-}
+};
