@@ -215,8 +215,12 @@ if (($device['os'] == 'routeros') && version_compare($device['version'], '7.7',
                 continue;
             }
 
-            $local_ifName = $lldp['lldpNeighborPortId'][$IndexId][1];
-            $local_port_id = find_port_id('gigabitEthernet ' . $local_ifName, null, $device['device_id']);
+            $interface = get_port_by_ifIndex($device['device_id'], $IndexId);
+            if (! $interface['port_id']) {
+                $local_ifName = $lldp['lldpNeighborPortId'][$IndexId][1];
+                $local_port_id = find_port_id('gigabitEthernet ' . $local_ifName, null, $device['device_id']);
+                $interface = get_port_by_id($local_port_id);
+            }
 
             $remote_device_id = find_device_id($lldp['lldpNeighborDeviceName'][$IndexId][1]);
             $remote_device_name = $lldp['lldpNeighborDeviceName'][$IndexId][1];
@@ -229,20 +233,22 @@ if (($device['os'] == 'routeros') && version_compare($device['version'], '7.7',
                     \LibreNMS\Util\Validate::hostname($remote_device_name) &&
                     ! can_skip_discovery($remote_device_name, $remote_device_ip) &&
                     Config::get('autodiscovery.xdp') === true) {
-                $remote_device_id = discover_new_device($remote_device_name, $device, 'LLDP', $local_ifName);
+                $remote_device_id = discover_new_device($remote_device_name, $device, 'LLDP', $interface);
             }
 
-            discover_link(
-                $local_port_id, //our port id from database
-                'lldp',
-                $remote_port_id, //remote port id from database if applicable
-                $remote_device_name, //remote device name from SNMP walk
-                $remote_port_descr, //remote port description from SNMP walk
-                null,
-                $remote_device_sysDescr, //remote device description from SNMP walk
-                $device['device_id'], //our device id
-                $remote_device_id //remote device id if applicable
-            );
+            if ($interface['port_id'] && $remote_device_name && $remote_port_descr) {
+                discover_link(
+                    $interface['port_id'], //our port id from database
+                    'lldp',
+                    $remote_port_id, //remote port id from database if applicable
+                    $remote_device_name, //remote device name from SNMP walk
+                    $remote_port_descr, //remote port description from SNMP walk
+                    null,
+                    $remote_device_sysDescr, //remote device description from SNMP walk
+                    $device['device_id'], //our device id
+                    $remote_device_id //remote device id if applicable
+                );
+            }
         }
     }
     echo PHP_EOL;
@@ -483,7 +489,7 @@ if (Config::get('autodiscovery.ospf') === true) {
 
 d_echo($link_exists);
 
-$sql = 'SELECT * FROM `links` AS L, `ports` AS I WHERE L.local_port_id = I.port_id AND I.device_id = ?';
+$sql = 'SELECT * FROM `links` AS L LEFT JOIN `ports` AS I ON L.local_port_id = I.port_id WHERE L.local_device_id = ?';
 foreach (dbFetchRows($sql, [$device['device_id']]) as $test) {
     $local_port_id = $test['local_port_id'];
     $remote_hostname = $test['remote_hostname'];
