@@ -21,6 +21,6 @@ foreach ($oids as $index => $entry) {
     $low_warn_limit = round_Nth($value * 0.75, 100);
     $low_limit = round_Nth($value * 0.5, 100);
     if (is_numeric($value)) {
-        discover_sensor($valid['sensor'], 'fanspeed', $device, $oid, $index, 'extreme-fanspeed', $descr, '1', '1', $low_limit, $low_warn_limit, $high_warn_limit, $high_limit, $value);
+        discover_sensor(null, 'fanspeed', $device, $oid, $index, 'extreme-fanspeed', $descr, '1', '1', $low_limit, $low_warn_limit, $high_warn_limit, $high_limit, $value);
     }
 }
