@@ -25,7 +25,7 @@ if (is_numeric($temp)) {
 
     $descr = 'UPS Battery Replacement Status';
     //Discover Sensors
-    discover_sensor($valid['sensor'], 'state', $device, $cur_oid, $index, $state_name, $descr, 1, 1, null, null, null, null, $temp, 'snmp', $index);
+    discover_sensor(null, 'state', $device, $cur_oid, $index, $state_name, $descr, 1, 1, null, null, null, null, $temp, 'snmp', $index);
 
     //Create Sensor To State Index
     create_sensor_to_state_index($device, $state_name, $index);
@@ -45,7 +45,7 @@ foreach ($cooling_status as $index => $data) {
     }
     create_state_index($state_name, $states);
 
-    discover_sensor($valid['sensor'], 'state', $device, $cur_oid, $cur_oid, 'apc', $state_name, 1, 1, null, null, null, null, $data['coolingUnitStatusDiscreteValueAsInteger']);
+    discover_sensor(null, 'state', $device, $cur_oid, $cur_oid, 'apc', $state_name, 1, 1, null, null, null, null, $data['coolingUnitStatusDiscreteValueAsInteger']);
     create_sensor_to_state_index($device, $state_name, $index);
 }
 
@@ -65,7 +65,7 @@ foreach ($cooling_unit as $index => $data) {
     }
     create_state_index($state_name, $states);
 
-    discover_sensor($valid['sensor'], 'state', $device, $cur_oid, $cur_oid, 'apc', $state_name, 1, 1, null, null, null, null, $data['coolingUnitExtendedDiscreteValueAsInteger']);
+    discover_sensor(null, 'state', $device, $cur_oid, $cur_oid, 'apc', $state_name, 1, 1, null, null, null, null, $data['coolingUnitExtendedDiscreteValueAsInteger']);
     create_sensor_to_state_index($device, $state_name, $index);
 }
 
@@ -83,7 +83,7 @@ foreach ($relays as $index => $data) {
 
     $current = apc_relay_state($data['emsOutputRelayControlOutputRelayCommand']);
     if (is_numeric($current)) {
-        discover_sensor($valid['sensor'], 'state', $device, $cur_oid, $cur_oid, $state_name, $state_name, 1, 1, null, null, null, null, $current);
+        discover_sensor(null, 'state', $device, $cur_oid, $cur_oid, $state_name, $state_name, 1, 1, null, null, null, null, $current);
         create_sensor_to_state_index($device, $state_name, $cur_oid);
     }
 }
@@ -105,7 +105,7 @@ foreach ($switched as $index => $data) {
 
     $current = apc_relay_state($data['emsOutletControlOutletCommand']);
     if (is_numeric($current)) {
-        discover_sensor($valid['sensor'], 'state', $device, $cur_oid, $cur_oid, $state_name, $state_name, 1, 1, null, null, null, null, $current);
+        discover_sensor(null, 'state', $device, $cur_oid, $cur_oid, $state_name, $state_name, 1, 1, null, null, null, null, $current);
         create_sensor_to_state_index($device, $state_name, $cur_oid);
     }
 }
@@ -132,7 +132,7 @@ foreach ($pre_cache['mem_sensors_status'] as $index => $data) {
     $divisor = 1;
     $multiplier = 1;
     if (is_numeric($current)) {
-        discover_sensor($valid['sensor'], 'state', $device, $cur_oid, $state_name . '.' . $index, $state_name, $state_name, 1, 1, null, null, null, null, $current);
+        discover_sensor(null, 'state', $device, $cur_oid, $state_name . '.' . $index, $state_name, $state_name, 1, 1, null, null, null, null, $current);
         create_sensor_to_state_index($device, $state_name, $state_name . '.' . $index);
     }
 
@@ -152,7 +152,7 @@ foreach ($pre_cache['mem_sensors_status'] as $index => $data) {
     $divisor = 1;
     $multiplier = 1;
     if (is_numeric($current)) {
-        discover_sensor($valid['sensor'], 'state', $device, $cur_oid, $state_name . '.' . $index, $state_name, $state_name, 1, 1, null, null, null, null, $current);
+        discover_sensor(null, 'state', $device, $cur_oid, $state_name . '.' . $index, $state_name, $state_name, 1, 1, null, null, null, null, $current);
         create_sensor_to_state_index($device, $state_name, $state_name . '.' . $index);
     }
 }
@@ -191,7 +191,7 @@ if ($apcContactData['uioInputContactStatusTableSize'] > 0) {
                 $index = $split_index[0];
             }
 
-            discover_sensor($valid['sensor'], 'state', $device, $cur_oid, $state_name . '.' . $index, $state_name, $state_name, 1, 1, null, null, null, null, $current);
+            discover_sensor(null, 'state', $device, $cur_oid, $state_name . '.' . $index, $state_name, $state_name, 1, 1, null, null, null, null, $current);
             create_sensor_to_state_index($device, $state_name, $state_name . '.' . $index);
         }
     }
@@ -225,7 +225,7 @@ if ($apcContactData['uioInputContactStatusTableSize'] > 0) {
             ];
             create_state_index($state_name, $states);
 
-            discover_sensor($valid['sensor'], 'state', $device, $cur_oid, $state_name . '.' . $index, $state_name, $state_name, 1, 1, null, null, null, null, $current);
+            discover_sensor(null, 'state', $device, $cur_oid, $state_name . '.' . $index, $state_name, $state_name, 1, 1, null, null, null, null, $current);
             create_sensor_to_state_index($device, $state_name, $state_name . '.' . $index);
         }
     }
