@@ -40,7 +40,7 @@ foreach ($tables as $tablevalue) {
             $descr = $tablevalue[3] . $index;
             $oid_for_entry = $tablevalue[5] . '.' . $index;
 
-            discover_sensor($valid['sensor'], 'state', $device, $oid_for_entry, $index, $state_name, $descr, 1, 1, null, null, null, null, $entry[$cur_oid], 'snmp');
+            discover_sensor(null, 'state', $device, $oid_for_entry, $index, $state_name, $descr, 1, 1, null, null, null, null, $entry[$cur_oid], 'snmp');
             create_sensor_to_state_index($device, $state_name, $index);
         }
     }
