@@ -12,5 +12,5 @@ foreach (explode("\n", $temps) as $i => $t) {
     // Sensors are reported as 2 * value
     $divisor = 2;
     $val = (cast_number($val) / $divisor);
-    discover_sensor($valid['sensor'], 'temperature', $device, $oid, zeropad($i + 1), 'avaya-ers', 'Unit ' . ($i + 1) . ' temperature', $divisor, 1, null, null, null, null, $val);
+    discover_sensor(null, 'temperature', $device, $oid, zeropad($i + 1), 'avaya-ers', 'Unit ' . ($i + 1) . ' temperature', $divisor, 1, null, null, null, null, $val);
 }
