@@ -31,11 +31,13 @@ if (! is_numeric($vars['alert_id'])) {
         $alert_msg_prefix .= ' id ' . $vars['alert_id'];
     }
     if (dbDelete('alert_rules', '`id` =  ?', [$vars['alert_id']])) {
+        Alert::where('rule_id', $vars['alert_id'])->delete();
+        AlertLog::where('rule_id', $vars['alert_id'])->delete();
         dbDelete('alert_device_map', 'rule_id=?', [$vars['alert_id']]);
         dbDelete('alert_group_map', 'rule_id=?', [$vars['alert_id']]);
         dbDelete('alert_location_map', 'rule_id=?', [$vars['alert_id']]);
         dbDelete('alert_transport_map', 'rule_id=?', [$vars['alert_id']]);
-        dbDelete('alert_template_map', 'alert_rule_id=?', [$vars['alert_id']]);
+        AlertTemplateMap::where('alert_rule_id', $vars['alert_id'])->delete();
         echo $alert_msg_prefix . ' has been deleted.';
         exit;
     } else {
