@@ -30,7 +30,7 @@ $colour_area_max = 'FFCCCC';
 $graph_max = 0;
 $unit_text = 'Mode';
 
-$gpsd = Rrd::name($device['hostname'], ['app', 'gpsd', $app['app_id']]);
+$gpsd = Rrd::name($device['hostname'], ['app', 'gpsd', $app->app_id]);
 if (Rrd::checkRrdExists($gpsd)) {
     $rrd_filename = $gpsd;
 } else {
