@@ -1251,10 +1251,6 @@ return [
             'description' => 'Визначає версію rrdtool на вашому сервері',
             'help' => 'Версії вищі за 1.5.5 підтримують всі функції що використовує LibreNMS, не встановлюйте значення вищі за наявну версію',
         ],
-        'service_poller_enabled' => [
-            'description' => 'Увімкнути опитування',
-            'help' => 'Вмикає процеси опитування. Визначає значення за замовчуванням для всіх вузлів.',
-        ],
         'service_poller_workers' => [
             'description' => 'Процеси опитування',
             'help' => 'Кількість процесів опитування які буде створено. Визначає значення за замовчуванням для всіх вузлів.',
@@ -1267,10 +1263,6 @@ return [
             'description' => 'Повторна спроба для недоступних пристроїв',
             'help' => 'Якщо пристрій недоступний при опитуванні. Визначає час який необхідно зачекати перед повторною спробою. Визначає значення за замовчуванням для всіх вузлів.',
         ],
-        'service_discovery_enabled' => [
-            'description' => 'Увімкнути віднайдення',
-            'help' => 'Увімкнути процеси віднайдення. Визначає значення за замовчуванням для всіх вузлів.',
-        ],
         'service_discovery_workers' => [
             'description' => 'Кількість процесів віднайдення',
             'help' => 'Кількість запущених процесів віднайдення. Занадто велике значення може викликати перевантаження. Визначає значення за замовчуванням для всіх вузлів.',
@@ -1279,10 +1271,6 @@ return [
             'description' => 'Частота віднайдення',
             'help' => 'Як часто виконувати віднайдення пристроїв. Визначає значення за замовчуванням для всіх вузлів. За замовчуванням 4 рази в день.',
         ],
-        'service_services_enabled' => [
-            'description' => 'Увімкнути перевірки сервісів',
-            'help' => 'Увімкнути процеси перевірки сервісів. Визначає значення за замовчуванням для всіх вузлів.',
-        ],
         'service_services_workers' => [
             'description' => 'Кількість процесів перевірки сервісів',
             'help' => 'Кількість процесів перевірки сервісів. Визначає значення за замовчуванням для всіх вузлів.',
@@ -1291,10 +1279,6 @@ return [
             'description' => 'Частота перевірки сервісів',
             'help' => 'Як часто запускати перевірки сервісів. Має відповідати частоті опитування. Визначає значення за замовчуванням для всіх вузлів.',
         ],
-        'service_billing_enabled' => [
-            'description' => 'Білінг увімкнено',
-            'help' => 'Увімкнути процеси білінгу. Визначає значення за замовчуванням для всіх вузлів.',
-        ],
         'service_billing_frequency' => [
             'description' => 'Частота білінгу',
             'help' => 'Як часто необхідно збирати інформацію білінгу. Визначає значення за замовчуванням для всіх вузлів.',
@@ -1303,18 +1287,10 @@ return [
             'description' => 'Частота обчислень білінгу',
             'help' => 'Як часто обчислювати використання ресурсів. Визначає значення за замовчуванням для всіх вузлів.',
         ],
-        'service_alerting_enabled' => [
-            'description' => 'Сповіщення увімкнено',
-            'help' => 'Увімкнути процес сповіщення. Визначає значення за замовчуванням для всіх вузлів.',
-        ],
         'service_alerting_frequency' => [
             'description' => 'Частота перевірки сповіщень',
             'help' => 'Як часто перевіряються правила сповіщень. Дані оновлюються відповідно до частоти опитування. Визначає значення за замовчуванням для всіх вузлів.',
         ],
-        'service_ping_enabled' => [
-            'description' => 'Fast Ping Увімкнено',
-            'help' => 'Fast Ping просто перевіряє пристрої на доступність. Визначає значення за замовчуванням для всіх вузлів.',
-        ],
         'service_update_enabled' => [
             'description' => 'Щоденне обслуговування увімкнено',
             'help' => 'Запускає скрипт обслуговування daily.sh та перезапускає сервіс диспетчер. Визначає значення за замовчуванням для всіх вузлів.',
