@@ -27,6 +27,7 @@
       </center>
     </div>
     <div class="col-md-5 text-right">
+      <button type=button value="mapselectall" id="map-selectallButton" class="btn btn-primary" onclick="network.selectNodes(network_nodes.getIds());" title="{{ __('map.custom.edit.map.multiselect_info') }}">{{ __('map.custom.edit.map.selectall') }}</button>
       <button type=button value="maprender" id="map-renderButton" class="btn btn-primary" style="display: none" onclick="CreateNetwork();">{{ __('map.custom.edit.map.rerender') }}</button>
       <button type=button value="mapsave" id="map-saveDataButton" class="btn btn-primary" style="display: none" onclick="saveMapData();">{{ __('map.custom.edit.map.save') }}</button>
       <button type=button value="maplist" id="map-listButton" class="btn btn-primary" onclick="mapList();">{{ __('map.custom.edit.map.list') }}</button>
@@ -59,7 +60,8 @@
 @endsection
 
 @section('javascript')
-<script type="text/javascript" src="{{ asset('js/vis.min.js') }}"></script>
+<script type="text/javascript" src="{{ asset('js/vis-network.min.js') }}"></script>
+<script type="text/javascript" src="{{ asset('js/vis-data.min.js') }}"></script>
 <script type="text/javascript" src="{{ asset('js/leaflet.js') }}"></script>
 <script type="text/javascript" src="{{ asset('js/L.Control.Locate.min.js') }}"></script>
 <script type="text/javascript" src="{{ asset('js/leaflet-image.js') }}"></script>
@@ -97,7 +99,8 @@
     var edge_nodes_map = [];
     var node_device_map = {};
     var custom_image_base = "{{ $base_url }}images/custommap/icons/";
-    var network_options = {{ Js::from($map_conf) }};
+    var nodeimage_base = '{{ route('maps.nodeimage.show', ['image' => '?' ]) }}'.replace("?", "");
+    var network_options = {{ Js::from($map_conf) }}
 
     function edgeNodesRemove(nm_id, edgeid) {
         // Remove old item from map if it exists
@@ -338,10 +341,14 @@
             if(data.edges.length > 0 || data.nodes.length > 0) {
                 // Make sure a node is not dragged outside the canvas
                 nodepos = network.getPositions(data.nodes);
+                legendMoved = false;
                 $.each( nodepos, function( nodeid, node ) {
                     if ( nodeid.startsWith("legend_") ) {
-                        // Make sure the moved node is still on the map
-                        fixNodePos(nodeid, node);
+                        // Only move the legend once
+                        if (legendMoved) {
+                            return;
+                        }
+                        legendMoved = true;
 
                         // Get the current node config
                         cur_node = network_nodes.get(nodeid);
@@ -350,7 +357,19 @@
                         legend.x = legend.x + node.x - cur_node.x;
                         legend.y = legend.y + node.y - cur_node.y;
 
+                        // Make sure the top of the legend is still on the map
+                        fixNodePos("legend", legend);
+
                         redrawLegend();
+
+                        // Make sure the bottom of the legend is still on the map
+                        legendEndNode = network_nodes.get("legend_" + (legend.steps - 1))
+                        moveUp = legendEndNode.y - network_height + {{ $vmargin }};
+                        if (moveUp > 0) {
+                            legend.y -= moveUp;
+                            redrawLegend();
+                        }
+
                         return;
                     }
                     let move = fixNodePos(nodeid, node);
@@ -453,6 +472,9 @@
     }
 
     function redrawLegend() {
+        // Save list of selected nodes because we are going to remove and re-add the legend
+        selectedNodes = network.selectionHandler.getSelectedNodes().map((n) => {return n.id});
+
         // Clear out the old legend
         old_nodes = network_nodes.get({filter: function(node) { return node.id.startsWith("legend_") }});
         old_nodes.forEach((node) => {
@@ -504,6 +526,11 @@
             }
             network_nodes.flush();
         }
+
+        // Re-select nodes if multiple nodes are selected
+        if (selectedNodes.length > 1) {
+            network.selectNodes(selectedNodes);
+        }
     }
 
     function editMapSuccess(data) {
@@ -531,6 +558,8 @@
     function editMapCancel() {
         mapSettingsReset();
         $('#mapModal').modal('hide');
+        $("#savemap-alert").attr("class", "col-sm-12");
+        $("#savemap-alert").text("");
     }
 
     function saveMapData() {
@@ -545,18 +574,23 @@
                 edgeid = node.id.split("_")[0];
                 edge1 = network_edges.get(edgeid + "_from");
                 edge2 = network_edges.get(edgeid + "_to");
-                edges[edgeid] = {id: edgeid, text_colour: edge1.font.color, text_size: edge1.font.size, text_face: edge1.font.face, from: edge1.from, to: edge2.from, showpct: (edge1.label != null && edge1.label.includes("xx%")), showbps: (edge1.label != null && edge1.label.includes("bps")), label: (node.label || ''), fixed_width: (edge1.width || null), port_id: edge1.title, style: edge1.smooth.type, mid_x: node.x, mid_y: node.y, reverse: (edgeid in edge_port_map ? edge_port_map[edgeid].reverse : false)};
+                edges[edgeid] = {id: edgeid, text_colour: edge1.font.color, text_size: edge1.font.size, text_face: edge1.font.face, text_align: edge1.font.align, from: edge1.from, to: edge2.from, showpct: (edge1.label != null && edge1.label.includes("xx%")), showbps: (edge1.label != null && edge1.label.includes("bps")), label: (node.label || ''), fixed_width: (edge1.width || null), port_id: edge1.title, style: edge1.smooth.type, mid_x: node.x, mid_y: node.y, reverse: (edgeid in edge_port_map ? edge_port_map[edgeid].reverse : false)};
             } else {
                 if(node.icon.code) {
                     node.icon = node.icon.code.charCodeAt(0).toString(16);
                 } else {
                     node.icon = null;
                 }
-                if("unselected" in node.image) {
+                if(node.image && "unselected" in node.image) {
                     if(node.image.unselected.indexOf(custom_image_base) == 0) {
                         node.image.unselected = node.image.unselected.replace(custom_image_base, "");
+                        node.nodeimage = null;
+                    } else if(node.image.unselected.indexOf(nodeimage_base) == 0) {
+                        node.nodeimage = node.image.unselected.replace(nodeimage_base, "");
+                        node.image = undefined;
                     } else {
-                        node.image = {};
+                        node.image = undefined;
+                        node.nodeimage = null;
                     }
                 }
                 nodes[node.id] = node;
@@ -697,7 +731,7 @@
                     node_cfg.borderWidth = node.border_width;
                     node_cfg.x = node.x_pos;
                     node_cfg.y = node.y_pos;
-                    node_cfg.font = {face: node.text_face, size: node.text_size, color: node.text_colour};
+                    node_cfg.font = {face: node.text_face, size: node.text_size, color: node.text_colour, background: '#FFFFFF'};
                     node_cfg.size = node.size;
                     node_cfg.color = {background: node.colour_bg, border: node.colour_bdr};
                     if(node.style == "icon") {
@@ -708,16 +742,21 @@
                     if(node.style == "image" || node.style == "circularImage") {
                         if(node.image) {
                             node_cfg.image = {unselected: custom_image_base + node.image};
+                        } else if(node.nodeimage) {
+                            node_cfg.image = {unselected: nodeimage_base + node.nodeimage};
                         } else if (node.device_image) {
                             node_cfg.image = {unselected: node.device_image};
                         } else {
                             // If we do not get a valid image from the database, use defaults
                             node_cfg.shape = newnodeconf.shape;
                             node_cfg.icon = newnodeconf.icon;
-                            node_cfg.image = newnodeconf.image;
+                            node_cfg.image = newnodeconf.image || undefined;
                         }
                     } else {
-                        node_cfg.image = {};
+                        node_cfg.image = undefined;
+                    }
+                    if(! ["ellipse", "circle", "database", "box", "text"].includes(node.style)) {
+                        node_cfg.font.background = "#FFFFFF";
                     }
 
                     if (network_nodes.get(nodeid)) {
@@ -743,8 +782,8 @@
                         arrows = {to: {enabled: true, scaleFactor: 0.6}, from: {enabled: false}};
                     }
 
-                    var edge1 = {id: edgeid + "_from", from: edge.custom_map_node1_id, to: edgeid + "_mid", arrows: arrows, font: {face: edge.text_face, size: edge.text_size, color: edge.text_colour}, smooth: {type: edge.style}};
-                    var edge2 = {id: edgeid + "_to", from: edge.custom_map_node2_id, to: edgeid + "_mid", arrows: arrows, font: {face: edge.text_face, size: edge.text_size, color: edge.text_colour}, smooth: {type: edge.style}};
+                    var edge1 = {id: edgeid + "_from", from: edge.custom_map_node1_id, to: edgeid + "_mid", arrows: arrows, font: {face: edge.text_face, size: edge.text_size, color: edge.text_colour, align: edge.text_align, background: '#FFFFFF'}, smooth: {type: edge.style}, arrowStrikethrough: false};
+                    var edge2 = {id: edgeid + "_to", from: edge.custom_map_node2_id, to: edgeid + "_mid", arrows: arrows, font: {face: edge.text_face, size: edge.text_size, color: edge.text_colour, align: edge.text_align, background: '#FFFFFF'}, smooth: {type: edge.style}, arrowStrikethrough: false};
                     if(edge.fixed_width) {
                         edge1.width = edge2.width = parseFloat(edge.fixed_width) || null;
                     }
