@@ -1,6 +1,8 @@
-#!/usr/local/bin/php-8.1
+#!/usr/local/bin/php-8.2
 <?php
 
+require realpath(__DIR__ . '/..') . '/includes/init.php';
+
 // Pulled from includes/polling/functions.inc.php
 function data_flatten($array, $prefix = '', $joiner = '_')
 {
@@ -147,7 +149,7 @@ if (! isset($options['S'])) {
 
 // Output snmprec data for snmpsim for use with testing.
 if (isset($options['s'])) {
-    $oid = string_to_oid($options['S']);
+    $oid = \LibreNMS\Util\Oid::ofString($options['S']);
     echo "1.3.6.1.2.1.1.1.0|4|Linux server 3.10.0-693.5.2.el7.x86_64 #1 SMP Fri Oct 20 20:32:50 UTC 2017 x86_64\n" .
         "1.3.6.1.2.1.1.2.0|6|1.3.6.1.4.1.8072.3.2.10\n" .
         "1.3.6.1.2.1.1.3.0|67|77550514\n" .
